@@ -23,8 +23,7 @@
 #include <kio/global.h>
 #include <kio/udsentry.h>
 #include <kio/authinfo.h>
-#include <kio/jobclasses.h> // for KIO::JobFlags
-#include <klocalizedstring.h>
+#include "job_base.h" // for KIO::JobFlags
 
 #include <QtCore/QByteArray>
 #include <QtNetwork/QHostInfo>
@@ -277,8 +276,8 @@ public:
      */
     int messageBox(MessageBoxType type, const QString &text,
                    const QString &caption = QString(),
-                   const QString &buttonYes = i18n("&Yes"),
-                   const QString &buttonNo = i18n("&No"));
+                   const QString &buttonYes = QString(),
+                   const QString &buttonNo = QString());
 
     /**
      * Call this to show a message box from the slave
@@ -297,8 +296,8 @@ public:
      */
     int messageBox(const QString &text, MessageBoxType type,
                    const QString &caption = QString(),
-                   const QString &buttonYes = i18n("&Yes"),
-                   const QString &buttonNo = i18n("&No"),
+                   const QString &buttonYes = QString(),
+                   const QString &buttonNo = QString(),
                    const QString &dontAskAgainName = QString());
 
     /**
@@ -760,9 +759,10 @@ public:
      * \note A call to this function can fail and return @p false,
      * if the UIServer could not be started for whatever reason.
      *
-     * \note Starting with KDE 4.7, this function will no longer store the password
-     * information automatically. If you want to store the password information in
-     * a persistent storage like KWallet, then you MUST call @ref cacheAuthentication.
+     * \note This function does not store the password information
+     * automatically (and has not since kdelibs 4.7). If you want to
+     * store the password information in a persistent storage like
+     * KWallet, then you MUST call @ref cacheAuthentication.
      *
      * @see checkCachedAuthentication
      * @param info  See AuthInfo.
@@ -803,9 +803,8 @@ public:
     /**
      * Caches @p info in a persistent storage like KWallet.
      *
-     * Starting with KDE 4.7, calling openPasswordDialog will no longer store
-     * passwords automatically for you. This was done to avoid accidental storage
-     * of incorrect or invalid password information.
+     * Note that calling openPasswordDialog does not store passwords
+     * automatically for you (and has not since kdelibs 4.7).
      *
      * Here is a simple example of how to use cacheAuthentication:
      *
